import {
IEventParam,
Loader,
Metadata,
Http,
I18n,
} from '@zeedhi/core';
import {
IterableComponentRender,
IButtonEvent,
DialogService,
Select,
// Dropdown,
Text,
} from '@zeedhi/common';
import {
} from '@zeedhi/teknisa-components-common';

export class WaybillLaunchController {
  private Utilities = Loader.getInstance('Utilities');

  public dishesTypesTitleVisibility: boolean = false;

  public productsTitleVisibility: boolean = false;

  public productsPaginationInDishesVisibility: boolean = false;

  public productsPaginationVisibility: boolean = false;

  public dishesTypesPaginationVisibility: boolean = false;

  public indexForProducts: number = 0;

  public paramsDeleteProduct: any;

  public paramsDeleteWaybill: any;

  public componentToBeDeleted: any;

  public deleteSuccessfully: string = 'Item excluído com sucesso.';

  public notEvolved: string = 'NÃO EVOLUÍDO';

  public evolved: string = 'EVOLUÍDO';

  public pending: string = 'PENDENTE';

  public deleteText: string = 'Deseja excluir o item selecionado?';

  public deleteTitle: string = 'Excluir item?';

  public closeConfirmationDialog: any = {
    click: () => DialogService.hide(),
  };

  public getProductsDatasourceDisheType({ component }: IEventParam<IterableComponentRender>) {
    const PlanningWithdrawalController = Loader.getInstance('PlanningWithdrawalController');
    const parentIterable = Metadata.getInstance<IterableComponentRender>('iterableCollapseCardDishesTypes');
    PlanningWithdrawalController.paramsForProductsQuery.CDPRATO = parentIterable.datasource.data[this.indexForProducts].CDPRATO;
    PlanningWithdrawalController.paramsForProductsQuery.CDTIPOPRAT = parentIterable.datasource.data[this.indexForProducts].CDTIPOPRAT;
    PlanningWithdrawalController.paramsForProductsQuery.CDFILAUXPRAT = parentIterable.datasource.data[this.indexForProducts].CDFILAUXPRAT;
    component.datasource.filter = PlanningWithdrawalController.paramsForProductsQuery;
    this.indexForProducts += 1;
    const htmlElement = document.getElementById(component.name);
    const parentElement = htmlElement?.parentElement;
    if (parentElement) {
        parentElement.style.padding = '0 8px';
    }
    component.datasource.get().finally(() => {
      this.indexForProducts = 0;
      if (component.datasource.limit >= component.datasource.total) {
        this.productsPaginationInDishesVisibility = false;
      } else {
        this.productsPaginationInDishesVisibility = true;
      }
      this.pendingDisheStylize({ component });
      });
  }

  // public collapseCardExpandedState({ component }: any) {
  //   if (component.props.expand === true) {
  //     component.props.expand = false;
  //   }
  //   if (component.props.expanded === false) {
  //     component.props.expanded = true;
  //   }
  // }

  public evolveStock({ component, event }: IButtonEvent) {
    if (event) {
      event.stopPropagation();
    }

    const params = component.name.split('_');
    const sendObject = {
      CDFILIAL: params[1],
      CDFILIMOVI: Metadata.getInstance<Select>('unitsForWithdrawal').value.CDFILIAL,
      NRLANCESTQ: Metadata.getInstance<IterableComponentRender>('detailCardWaybills').datasource.data[0].NRLANCESTQ,
      NRCARDAPIO: params[2],
    };

    Http.post('/updateStock', {
      requestType: 'Row',
      row: sendObject,
    }).then((response) => {
      if (response.data.error) {
        this.Utilities.failMessage(I18n.translate(response.data.error));
      } else {
        const stockUpdated = I18n.translate(this.Utilities.stockUpdated);
        this.Utilities.successMessage(stockUpdated);
      }
    });
  }

  public deleteProductDialog({ component, event }: IButtonEvent) {
    if (event) {
      event.stopPropagation();
    }
    const itens = component.name.split('_');
    if (component && component.parent && component.parent.parent) {
      this.componentToBeDeleted = component.parent.parent;
    }
    const sendObject = [{
      CDFILIAL: itens[1],
      NRCARDAPIO: itens[2],
      NRLANCESTQ: itens[3],
      CDFILANCESTQ: itens[4],
      NRRETIRADA: itens[5],
      NRSEQUITRETI: itens[6],
    }];
    this.paramsDeleteProduct = sendObject;
    const dialogParams = {
      deleteTitle: I18n.translate(this.deleteTitle),
      deleteText: I18n.translate(this.deleteText),
    };
    this.Utilities.showConfirmationDialog(dialogParams.deleteTitle, dialogParams.deleteText, this.closeConfirmationDialog, this.deleteProductButton);
  }

  public deleteProductButton: any = {
    click: () => this.deleteProduct(),
  };

  public deleteProduct() {
    const sendObject = this.paramsDeleteProduct;
    Http.post('/deleteProduct', {
      requestType: 'DataSet',
      dataset: sendObject,
    }).then((response) => {
      if (response.data.error) {
        this.Utilities.failMessage(I18n.translate(response.data.error));
        DialogService.hide();
      } else {
        DialogService.hide();
        this.componentToBeDeleted.isVisible = false;
        const deleteSuccessfully = I18n.translate(this.deleteSuccessfully);
        this.Utilities.successMessage(deleteSuccessfully);
      }
    });
  }

  public deleteWaybillDialog({ component }: IButtonEvent) {
    const params = component.name.split('_');
    const sendObject = {
      CDFILIAL: params[1],
      CDFILIMOVI: params[5],
      NRRETIRADA: params[2],
      NRCARDAPIO: params[3],
      NRLANCESTQ: params[4],
    };
    this.paramsDeleteWaybill = sendObject;
    const dialogParams = {
      deleteTitle: I18n.translate(this.deleteTitle),
      deleteText: I18n.translate(this.deleteText),
    };
    this.Utilities.showConfirmationDialog(dialogParams.deleteTitle, dialogParams.deleteText, this.closeConfirmationDialog, this.deleteWaybillButton);
  }

  public deleteWaybillButton: any = {
    click: () => this.deleteWaybill(),
  };

  public deleteWaybill() {
    const sendObject = this.paramsDeleteWaybill;
    const withdrawalsCards = Metadata.getInstance<IterableComponentRender>('iterableWaybillCard');
    Http.post('/deleteWaybill', {
      requestType: 'Row',
      row: sendObject,
    }).then((response) => {
      if (response.data.error) {
        this.Utilities.failMessage(I18n.translate(response.data.error));
        DialogService.hide();
      } else {
        withdrawalsCards.reload();
        DialogService.hide();
        const deleteSuccessfully = I18n.translate(this.deleteSuccessfully);
        this.Utilities.successMessage(deleteSuccessfully);
      }
    });
  }

  public copyAmount() {
    const collapseCardIterable = Metadata.getInstance<IterableComponentRender>('iterableCollapseCardDishesTypes');
    console.warn(collapseCardIterable);
  }

  public pendingDisheStylize({ component }: any) {
    const datasource = component.datasource.data;
    datasource.forEach((item: any) => {
      if (item.IDEVOLESTOQ === 'N') {
        component.parent.header[0].text = `<span style='color: #ff6700;'>${component.parent.header[0].text}</span>`;
      }
    });
  }

  public stylizeProductStatus({ component }: IEventParam<Text>) {
    const evolved = I18n.translate(this.evolved);
    const pending = I18n.translate(this.pending);
    const notEvolved = I18n.translate(this.notEvolved);
    const params: any = component.name.split('_');
    if (params[0] === 'null') {
      params[0] = null;
    }

    if (params[0] !== null && params[1] === 'N') {
      component.text = `<span  style='background-color: #dee2e6; color: red; font-size: 13px;'>${notEvolved}</span>`;
    }
    if (params[0] === null) {
      component.text = `<span  style='background-color:#dee2e6; color: #ff6700; font-size: 13px;'>${pending}</span>`;
    }
    if (params[0] !== null && params[1] === 'S') {
      component.text = `<span  style='background-color: #dee2e6; color: green; font-size: 13px;'>${evolved}</span>`;
    }
  }
}
